import { Link } from 'react-router-dom'
import { loadSavedChecklists, exportChecklistToJSON } from '../hooks/useLocalStorage'
import { useState } from 'react'
import { Card, Heading, Text, Button, Flex, Box } from '@radix-ui/themes'
import { Share1Icon, DownloadIcon, TrashIcon } from '@radix-ui/react-icons'

interface SavedChecklistsProps {
  className?: string
}

export default function SavedChecklists({ className = '' }: SavedChecklistsProps) {
  const [savedChecklists, setSavedChecklists] = useState<{ uuid: string; name: string; lastOpened?: string }[]>(loadSavedChecklists())
  const [exportingChecklist, setExportingChecklist] = useState<string | null>(null)
  
  const handleForgetCheckList = (uuid: string): void => {
    const updatedChecklists = savedChecklists.filter((checklist: { uuid: string }) => checklist.uuid !== uuid)
    localStorage.setItem('gocheck-saved-checklists', JSON.stringify(updatedChecklists))
    setSavedChecklists(updatedChecklists)
  }

  const handleExportChecklist = async (uuid: string, name: string): Promise<void> => {
    setExportingChecklist(uuid)
    try {
      await exportChecklistToJSON(uuid, name)
    } catch {
      alert('Failed to export checklist')
    } finally {
      setExportingChecklist(null)
    }
  }


  if (savedChecklists.length === 0) {
    return (
      <Card size="3" className={className}>
        <Flex direction="column" align="center" justify="center" py="9">
          <Text size="9" color="gray" mb="4">📋</Text>
          <Heading size="5" mb="2">No checklists yet</Heading>
          <Text color="gray">Create your first checklist above to get started!</Text>
        </Flex>
      </Card>
    )
  }

  return (
    <Card size="3" className={className}>
      <Heading size="5" mb="5">Your Checklists</Heading>
      <Flex direction="column" gap="3">
        {savedChecklists.map((checklist) => (
          <Card key={checklist.uuid} size="2">
            <Flex direction={{ initial: 'column', sm: 'row' }} justify="between" gap="3">
              <Box>
                <Heading size="3" mb="1">{checklist.name}</Heading>
                <Text size="2" color="gray">
                  Last opened: {checklist.lastOpened ? new Date(checklist.lastOpened).toLocaleString() : 'Never'}
                </Text>
              </Box>
              <Flex gap="2" wrap="wrap">
                <Link to={`/${checklist.uuid}`}>
                  <Button size="2">
                    Open
                  </Button>
                </Link>
                <Button 
                  size="2"
                  color="green"
                  onClick={() => {
                    const url = `${window.location.origin}/${checklist.uuid}`
                    navigator.clipboard.writeText(url).then(() => {
                      alert('Checklist link copied to clipboard! ' + url)
                    }).catch(() => {
                      const textArea = document.createElement('textarea')
                      textArea.value = url
                      document.body.appendChild(textArea)
                      textArea.select()
                      document.execCommand('copy')
                      document.body.removeChild(textArea)
                      alert('Checklist link copied to clipboard!')
                    })
                  }}
                >
                  <Share1Icon />
                  Share
                </Button>
                <Button 
                  size="2"
                  color="violet"
                  onClick={() => handleExportChecklist(checklist.uuid, checklist.name)}
                  disabled={exportingChecklist === checklist.uuid}
                >
                  <DownloadIcon />
                  {exportingChecklist === checklist.uuid ? 'Exporting...' : 'Export'}
                </Button>
                <Button 
                  size="2"
                  color="red"
                  onClick={() => handleForgetCheckList(checklist.uuid)}
                >
                  <TrashIcon />
                  Forget
                </Button>
              </Flex>
            </Flex>
          </Card>
        ))}
      </Flex>
    </Card>
  )
} 